/*  This file is part of qxv,
 *  http://labs.freehackers.org/projects/show/qxv

   Copyright (C) 2010 Thomas Capricelli <orzel@freehackers.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of version 2 of the GNU General Public
   License as published by the Free Software Foundation

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/
#ifndef APPLICATION_H
#define APPLICATION_H

#include <QApplication>
#include <QStringList>
#include <QImage>
#include <QPrinter>

class QAction;
class QLabel;
class QMenu;
class QScrollArea;
class QScrollBar;

class DisplayWidget;
class DisplayWindow;
class ControlWindow;
class QKeyEvent;

class Application : public QApplication
{
    Q_OBJECT
    friend class DisplayWidget;

public:
    Application(int & argc, char ** argv);
    ~Application(void);

    void doLoad(const QString &filename);
    /** Given a 'pos' inside the currently displayed widget, update it to
      * the corresponding value in the original image reference, and
      * returns the QColor for this pixel  */
    QColor getPixel(QPoint &pos) const;
private slots:
    void open(void);
    void print(void);
    void about(void);

    void receiveKey(QKeyEvent *event);
    void rmbClicked(void);
    void displayWindowResized(int width, int height);

    // xv stuff
    void shrink(void);
    void grow(void);
    void bigShrink(void);
    void bigGrow(void);
    void rotateClockwise(void);
    void rotateCounterClockwise(void);
    void backToOriginal(void);
    void flipHorizontal(void);
    void flipVertical(void);
    void smooth(void);
    void crop(void);
    void nextImage(void);
    void previousImage(void);
    void resizeOriginal(void);
    void resizeMaximum(void);
    void resizeMaximumRatio(void);
    void resizeReAspect(void);
    void resize4x3(void);
    
    void loadImage(void);
private:
    void createActions(void);
    void createMenus(void);
    void updateImage(void);

#ifndef QT_NO_PRINTER
    QPrinter printer;
#endif

    QAction *openAct;
    QAction *printAct;
    QAction *quitAct;
    QAction *aboutAct;

    // xv actions
    QAction *shrinkAct;
    QAction *growAct;
    QAction *bigShrinkAct;
    QAction *bigGrowAct;
    QAction *rotateClockwiseAct;
    QAction *rotateCounterClockwiseAct;
    QAction *backToOriginalAct;
    QAction *flipHorizontalAct; // wrt to vertical
    QAction *flipVerticalAct; // wrt to horizontal
    QAction *smoothAct;
    QAction *cropAct;
    QAction *resizeOriginalAct;
    QAction *resizeMaximumAct;
    QAction *resizeMaximumRatioAct;
    QAction *resizeReAspectAct;
    QAction *resize4x3Act;

    QMenu *fileMenu;
    QMenu *viewMenu;
    QMenu *helpMenu;

    DisplayWindow * displayWindow;
    DisplayWidget *displayWidget;
    ControlWindow *controlWindow;

    QImage originalImage;  // the very, true, genuine, original image
    QImage currentImage;   // the image with all modifications DESPITE size changes
    QImage displayedImage; // currently being displayed
    QRect  displayedRect;  // describe the part of the original image which is displayed

    QStringList filenames;
};

#endif // APPLICATION_H

