/*  This file is part of qxv,
 *  http://labs.freehackers.org/projects/show/qxv

   Copyright (C) 2010 Thomas Capricelli <orzel@freehackers.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of version 2 of the GNU General Public
   License as published by the Free Software Foundation

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#include <QtGui>
#include "controlwindow.h"
#include "application.h"
#include "ui_controlswidget.h"

ControlWindow::ControlWindow(Application *application, const QStringList &filenames, Qt::WindowFlags flags)
    : QMainWindow(0, flags)
{
    QWidget *widget = new QWidget(this);
    ui= new Ui_controlsWidget;
    ui->setupUi(widget);
    setCentralWidget(widget);
    setWindowTitle(tr("qxv controls"));
    resize(500, 400);

    connect( ui->shrinkButton, SIGNAL(clicked()), application, SLOT(shrink()));
    ui->shrinkButton->setIcon(QIcon(":images/shrink.png"));
    connect( ui->growButton, SIGNAL(clicked()), application, SLOT(grow()));
    ui->growButton->setIcon(QIcon(":images/grow.png"));
    connect( ui->rotateCWButton, SIGNAL(clicked()), application, SLOT(rotateClockwise()));
    ui->rotateCWButton->setIcon(QIcon(":images/rotateclockwise.png"));
    connect( ui->rotateCCWButton, SIGNAL(clicked()), application, SLOT(rotateCounterClockwise()));
    ui->rotateCCWButton->setIcon(QIcon(":images/rotatecounterclockwise.png"));
    connect( ui->quitButton, SIGNAL(clicked()), application, SLOT(quit()));
    connect( ui->aboutButton, SIGNAL(clicked()), application, SLOT(about()));

    connect( ui->nextButton, SIGNAL(clicked()), application, SLOT(nextImage()));
    connect( ui->previousButton, SIGNAL(clicked()), application, SLOT(previousImage()));

    //ui->fliphorizontalButton->setIcon(QIcon(":images/fliphorizontal.png"));
    //ui->flipverticalButton->setIcon(QIcon(":images/flipvertical.png"));

//    connect( backToOriginalButton, SIGNAL(clicked()), application, SLOT(backToOriginal()));
//    connect( flipHorizontalButton, SIGNAL(clicked()), application, SLOT(flipHorizontal()));
//    connect( flipVerticalButton, SIGNAL(clicked()), application, SLOT(flipVertical()));
//    connect( smoothButton, SIGNAL(clicked()), application, SLOT(smooth()));

    ui->imagesList->addItems(filenames);
    ui->imagesList->setCurrentRow(0);
    connect(ui->imagesList, SIGNAL(itemActivated(QListWidgetItem *)), application, SLOT(loadImage()));

}

int ControlWindow::getFileNumber(void) const
{
    return ui->imagesList->currentRow();
}

void ControlWindow::selectImage(int idx)
{
    ui->imagesList->setCurrentRow(idx);
}
