/*  This file is part of qxv,
 *  http://labs.freehackers.org/projects/show/qxv

   Copyright (C) 2010 Thomas Capricelli <orzel@freehackers.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of version 2 of the GNU General Public
   License as published by the Free Software Foundation

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/
#ifndef DISPLAYWIDGET_H
#define DISPLAYWIDGET_H

#include <QLabel>

class RubberBand;
class Application;

class DisplayWidget: public QLabel
{
    Q_OBJECT

public:
    DisplayWidget(QWidget * parent, const Application &application, Qt::WindowFlags f = 0);

    void syncPixmap(void);
    QRect selection(void);

signals:
    void emitKey(QKeyEvent *event);
    void rmbClicked(void);
protected:
    void keyPressEvent(QKeyEvent *event);
    void mousePressEvent(QMouseEvent *event);
    void mouseMoveEvent(QMouseEvent *event);
    void mouseReleaseEvent(QMouseEvent *event);
    void updatePixelInformation(QPoint pos);

    RubberBand *rubberBand;
    QPoint origin;
    QPoint originOriginal;
    enum { 
        DragNone,
        DragSelection,
        DragPixelInformation,
    } dragState;
    bool displayInformationDisplayedOnTop;

    /** Reference to the QImage handled by application */
    const Application &application;
    /** We syng the QImage to this QPixmap which is actually displayed */
    QPixmap displayedPixmap;
};

#endif //DISPLAYWIDGET_H

